#!/bin/sh
version=10.1.1
libversion=0.0.0
bindir=/usr/bin
mandir=/usr/man
osname=`uname -s`
if [ "$osname" = "OS400" ]; then
   bindir=/QOpenSys/usr/bin
   mandir=/QOpenSys/usr/man
   if test -z "$1" ; then
      installdir=/QOpenSys/usr/local
   else
      installdir="/QOpenSys/$1"
   fi
elif test -z "$1" ; then
   installdir=/usr/local
else
   installdir="/$1"
fi
umask 022
cd `dirname $0`/usr/local
logfile=$installdir/share/tbarcode10/install.log

CheckFiles()
{
  if test ! -d include
  then
    echo "Error: Could not find directory 'include'!"
    return 1;
  fi
   
  if test ! -d lib
  then
    echo "Error: Could not find directory 'lib'!"
    return 1;
  fi
  
  if test ! -d share
  then
    echo "Error: Could not find directory 'share'!"
    return 1;
  fi
  
  return 0;
}

InstallFiles()
{
  if test ! -d $installdir
  then
		mkdir -p $installdir
  fi

  echo "Copying tbarcode files..."
	cp -R share $installdir
	echo "# Installation log (" `date` ")" >> $logfile
	find share -type f | nawk -v DIR=$installdir '{ print DIR "/" $1 }' >> $logfile

  echo "Copying include files..."
	cp -R include $installdir
	find include -type f | nawk -v DIR=$installdir '{ print DIR "/" $1 }' >> $logfile

  echo "Copying libraries..."
  cp -R lib $installdir
	find lib -type f | nawk -v DIR=$installdir '{ print DIR "/" $1 }' >> $logfile
}

create_link()
{
	echo "$2 # link to $1" >> $logfile
	ln -sf $1 $2 2> /dev/null
}

PostInstallationProcedure()
{
	if test -f $installdir/lib/libtbarcode10.so.$libversion
	then
		echo "Registering TBarCode Library..."
		create_link $installdir/lib/libtbarcode10.so.$libversion $installdir/lib/libtbarcode10.so.0
		create_link $installdir/lib/libtbarcode10.so.$libversion $installdir/lib/libtbarcode10.so
	fi
  
  echo "Creating link for TBarCode executable..."
  create_link $installdir/share/tbarcode10/tbarcode $bindir/tbarcode
  if test $? -ne 0
  then
    echo "Warning: Could not create link to tbarcode in $bindir !"
  fi

  echo "Creating link for TBarCode manual..."
  create_link $installdir/share/tbarcode10/tbarcode.1 $mandir/man1
  if test $? -ne 0
  then
    echo "Warning: Could not create link to tbarcode manual in $mandir !"
  fi

	if test -f $installdir/share/tbarcode10/filterlp_ps.fd
	then
		echo "Registering TBarCode printing filters..."
		/usr/sbin/lpfilter -f tbarcode_ps -F $installdir/share/tbarcode10/filterlp_ps.fd
		/usr/sbin/lpfilter -f tbarcode_pcl -F $installdir/share/tbarcode10/filterlp_pcl.fd
	fi

  echo "Setting file permissions..."
  chmod a+r $installdir/share/tbarcode10/*
  chmod a+x $installdir/share/tbarcode10/*.sh
  chmod a+x $installdir/share/tbarcode10/tbarcode
  if test $? -ne 0
  then
    echo "Error: chmod failed!"
    return 1;
  fi
  return 0;
}

LICENSE_FILE=tecit_license_agreement.txt

echo " TBarCode for $osname - Installation"
echo " -----------------------------------"
echo ""

# Display license agreeement
if test -f $LICENSE_FILE
  then
  cat $LICENSE_FILE | more
  agreed=""
  while [ -z "$agreed" ]; do
    echo ""
    echo "Do you agree to the above license terms? [yes or no]"
    read reply leftover
    case $reply in
      [yY] | [yY][eE][sS])
         agreed=1
         ;;
      [nN] | [nN][oO])
         echo "If you don't agree to the license you can't install this software"
         exit 1
         ;;
     esac
   done
else
  echo "License agreement $LICENSE_FILE not found!"
  exit 1;
fi

if CheckFiles && InstallFiles && PostInstallationProcedure
then    
  echo "Installation finished."
  echo "Do you want to print a test case using the newly installed TBarCodeX? [y or n]"
  read reply
  case $reply in
    [yY] | [yY][eE][sS])
      /usr/local/share/tbarcode10/tbarcode --output=barcode.eps --barcode=20 --data="abc1234"
      ;;
  esac
  exit 0
else
  echo "Installation aborted."
  exit 1
fi

